NML documentation

# Warnings

Sometimes NML gives warnings that might be cryptic or you have no idea why they are given. This section will list these warnings.

IMAGE at [x: X, y: Y]: I of J pixels (K%) are pure white
This warning is generated when pixels with palette index 255, or RGB colour 0xFFFFFF, are found. These so-called pure white pixels are not used by OpenTTD, or TTDPatch, as they do not work with colour remaps such as the "transparency" colour remap. The pure white is used around the sprites in the PCX files that GRFCodec generates, which made pure white images with sprites common in NewGRF development. As such the pure white pixel test is also a way to detect so cases where the position or size of the sprite is incorrect, i.e. when it covers the white pixels around the sprite.